@@ -50,7 +50,7 @@ static void chooser_set_aosd_color (GtkColorButton * chooser, const aosd_color_t
   GdkColor gdk_color = {0, (uint16_t) color->red, (uint16_t) color->green, (uint16_t) color->blue};
 
   gtk_color_button_set_color (chooser, & gdk_color);
-  gtk_color_button_set_use_alpha (chooser, TRUE);
+  gtk_color_button_set_use_alpha (chooser, true);
   gtk_color_button_set_alpha (chooser, color->alpha);
 }
 
@@ -91,7 +91,7 @@ aosd_cb_configure_position_expose ( GtkWidget * darea ,
   cairo_fill ( cr );
   cairo_destroy (cr);
 
-  return FALSE;
+  return false;
 }
 
 
@@ -104,7 +104,7 @@ aosd_cb_configure_position_placement_commit ( GtkWidget * grid , aosd_cfg_t * cf
   while ( list_iter != nullptr )
   {
     GtkWidget *placbt = (GtkWidget *) list_iter->data;
-    if ( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(placbt) ) == TRUE )
+    if ( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(placbt) ) == true )
     {
       cfg->position.placement = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(placbt),"value"));
       break;
@@ -157,23 +157,23 @@ aosd_ui_configure_position ( aosd_cfg_t * cfg )
   int monitors_num = gdk_screen_get_n_monitors( gdk_screen_get_default() );
   int i = 0;
 
-  pos_vbox = gtk_vbox_new( FALSE , 4 );
+  pos_vbox = gtk_vbox_new( false , 4 );
   gtk_container_set_border_width( GTK_CONTAINER(pos_vbox) , 6 );
 
   pos_placement_frame = gtk_frame_new( _("Placement") );
-  pos_placement_hbox = gtk_hbox_new( FALSE , 0 );
+  pos_placement_hbox = gtk_hbox_new( false , 0 );
   gtk_container_set_border_width( GTK_CONTAINER(pos_placement_hbox) , 6 );
   gtk_container_add( GTK_CONTAINER(pos_placement_frame) , pos_placement_hbox );
-  gtk_box_pack_start( GTK_BOX(pos_vbox) , pos_placement_frame , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(pos_vbox) , pos_placement_frame , false , false , 0 );
 
-  pos_placement_grid = gtk_table_new (0, 0, FALSE);
+  pos_placement_grid = gtk_table_new (0, 0, false);
   for ( i = 0 ; i < 9 ; i++ )
   {
     if ( i == 0 )
       pos_placement_bt[i] = gtk_radio_button_new( nullptr );
     else
       pos_placement_bt[i] = gtk_radio_button_new_from_widget( GTK_RADIO_BUTTON(pos_placement_bt[0]) );
-    gtk_toggle_button_set_mode( GTK_TOGGLE_BUTTON(pos_placement_bt[i]) , FALSE );
+    gtk_toggle_button_set_mode( GTK_TOGGLE_BUTTON(pos_placement_bt[i]) , false );
     pos_placement_bt_darea[i] = gtk_drawing_area_new();
     gtk_widget_set_size_request( pos_placement_bt_darea[i] , 40 , 40 );
     gtk_container_add( GTK_CONTAINER(pos_placement_bt[i]) , pos_placement_bt_darea[i] );
@@ -183,14 +183,14 @@ aosd_ui_configure_position ( aosd_cfg_t * cfg )
                                (i % 3) , (i % 3) + 1 , (i / 3) , (i / 3) + 1 );
     g_object_set_data( G_OBJECT(pos_placement_bt[i]) , "value" , GINT_TO_POINTER(i+1) );
     if ( cfg->position.placement == (i+1) )
-      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(pos_placement_bt[i]) , TRUE );
+      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(pos_placement_bt[i]) , true );
   }
-  gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , pos_placement_grid , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , pos_placement_grid , false , false , 0 );
   aosd_cb_list.append( pos_placement_grid , aosd_cb_configure_position_placement_commit );
 
-  gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , gtk_vseparator_new() , FALSE , FALSE , 6 );
+  gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , gtk_vseparator_new() , false , false , 6 );
 
-  pos_offset_grid = gtk_table_new (0, 0, FALSE);
+  pos_offset_grid = gtk_table_new (0, 0, false);
   gtk_table_set_row_spacings( GTK_TABLE(pos_offset_grid) , 4 );
   gtk_table_set_col_spacings( GTK_TABLE(pos_offset_grid) , 4 );
   pos_offset_x_label = gtk_label_new( _( "Relative X offset:" ) );
@@ -214,12 +214,12 @@ aosd_ui_configure_position ( aosd_cfg_t * cfg )
   g_object_set_data( G_OBJECT(pos_offset_grid) , "maxsize_width" , pos_maxsize_width_spinbt );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(pos_maxsize_width_spinbt) , cfg->position.maxsize_width );
   gtk_table_attach_defaults( GTK_TABLE(pos_offset_grid) , pos_maxsize_width_spinbt , 1 , 2 , 2 , 3 );
-  gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , pos_offset_grid , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(pos_placement_hbox) , pos_offset_grid , false , false , 0 );
   aosd_cb_list.append( pos_offset_grid , aosd_cb_configure_position_offset_commit );
   aosd_cb_list.append( pos_offset_grid , aosd_cb_configure_position_maxsize_commit );
 
   pos_multimon_frame = gtk_frame_new( _("Multi-Monitor options") );
-  pos_multimon_hbox = gtk_hbox_new( FALSE , 4 );
+  pos_multimon_hbox = gtk_hbox_new( false , 4 );
   gtk_container_set_border_width( GTK_CONTAINER(pos_multimon_hbox) , 6 );
   gtk_container_add( GTK_CONTAINER(pos_multimon_frame), pos_multimon_hbox );
   pos_multimon_label = gtk_label_new( _("Display OSD using:") );
@@ -233,9 +233,9 @@ aosd_ui_configure_position ( aosd_cfg_t * cfg )
   }
   gtk_combo_box_set_active( GTK_COMBO_BOX(pos_multimon_combobox) , (cfg->position.multimon_id + 1) );
   aosd_cb_list.append( pos_multimon_combobox , aosd_cb_configure_position_multimon_commit );
-  gtk_box_pack_start( GTK_BOX(pos_multimon_hbox) , pos_multimon_label , FALSE , FALSE , 0 );
-  gtk_box_pack_start( GTK_BOX(pos_multimon_hbox) , pos_multimon_combobox , FALSE , FALSE , 0 );
-  gtk_box_pack_start( GTK_BOX(pos_vbox) , pos_multimon_frame , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(pos_multimon_hbox) , pos_multimon_label , false , false , 0 );
+  gtk_box_pack_start( GTK_BOX(pos_multimon_hbox) , pos_multimon_combobox , false , false , 0 );
+  gtk_box_pack_start( GTK_BOX(pos_vbox) , pos_multimon_frame , false , false , 0 );
 
   return pos_vbox;
 }
@@ -245,11 +245,11 @@ static GtkWidget *
 aosd_ui_configure_animation_timing ( char * label_string )
 {
   GtkWidget *hbox, *desc_label, *spinbt;
-  hbox = gtk_hbox_new( FALSE , 4 );
+  hbox = gtk_hbox_new( false , 4 );
   desc_label = gtk_label_new( label_string );
   spinbt = gtk_spin_button_new_with_range( 0 , 99999 , 1 );
-  gtk_box_pack_start( GTK_BOX(hbox) , desc_label , FALSE , FALSE , 0 );
-  gtk_box_pack_start( GTK_BOX(hbox) , spinbt , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(hbox) , desc_label , false , false , 0 );
+  gtk_box_pack_start( GTK_BOX(hbox) , spinbt , false , false , 0 );
   g_object_set_data( G_OBJECT(hbox) , "spinbt" , spinbt );
   return hbox;
 }
@@ -275,29 +275,29 @@ aosd_ui_configure_animation ( aosd_cfg_t * cfg )
   GtkWidget *ani_timing_fadein_widget, *ani_timing_fadeout_widget, *ani_timing_stay_widget;
   GtkSizeGroup *sizegroup;
 
-  ani_vbox = gtk_vbox_new( FALSE , 0 );
+  ani_vbox = gtk_vbox_new( false , 0 );
   gtk_container_set_border_width( GTK_CONTAINER(ani_vbox) , 6 );
 
-  ani_timing_hbox = gtk_hbox_new( FALSE , 0 );
+  ani_timing_hbox = gtk_hbox_new( false , 0 );
   ani_timing_frame = gtk_frame_new( _("Timing (ms)") );
   gtk_container_set_border_width( GTK_CONTAINER(ani_timing_hbox) , 6 );
   gtk_container_add( GTK_CONTAINER(ani_timing_frame) , ani_timing_hbox );
-  gtk_box_pack_start( GTK_BOX(ani_vbox) , ani_timing_frame , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(ani_vbox) , ani_timing_frame , false , false , 0 );
 
   ani_timing_stay_widget = aosd_ui_configure_animation_timing( _("Display:") );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(g_object_get_data(
     G_OBJECT(ani_timing_stay_widget),"spinbt")) , cfg->animation.timing_display );
-  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , ani_timing_stay_widget , TRUE , TRUE , 0 );
-  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , gtk_vseparator_new() , FALSE , FALSE , 4 );
+  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , ani_timing_stay_widget , true , true , 0 );
+  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , gtk_vseparator_new() , false , false , 4 );
   ani_timing_fadein_widget = aosd_ui_configure_animation_timing( _("Fade in:") );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(g_object_get_data(
     G_OBJECT(ani_timing_fadein_widget),"spinbt")) , cfg->animation.timing_fadein );
-  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , ani_timing_fadein_widget , TRUE , TRUE , 0 );
-  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , gtk_vseparator_new() , FALSE , FALSE , 4 );
+  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , ani_timing_fadein_widget , true , true , 0 );
+  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , gtk_vseparator_new() , false , false , 4 );
   ani_timing_fadeout_widget = aosd_ui_configure_animation_timing( _("Fade out:") );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON(g_object_get_data(
     G_OBJECT(ani_timing_fadeout_widget),"spinbt")) , cfg->animation.timing_fadeout );
-  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , ani_timing_fadeout_widget , TRUE , TRUE , 0 );
+  gtk_box_pack_start( GTK_BOX(ani_timing_hbox) , ani_timing_fadeout_widget , true , true , 0 );
   g_object_set_data( G_OBJECT(ani_timing_hbox) , "display" ,
     g_object_get_data(G_OBJECT(ani_timing_stay_widget),"spinbt") );
   g_object_set_data( G_OBJECT(ani_timing_hbox) , "fadein" ,
@@ -318,10 +318,10 @@ static void
 aosd_cb_configure_text_font_shadow_toggle ( GtkToggleButton * shadow_togglebt ,
                                             void * shadow_colorbt )
 {
-  if ( gtk_toggle_button_get_active( shadow_togglebt ) == TRUE )
-    gtk_widget_set_sensitive( GTK_WIDGET(shadow_colorbt) , TRUE );
+  if ( gtk_toggle_button_get_active( shadow_togglebt ) == true )
+    gtk_widget_set_sensitive( GTK_WIDGET(shadow_colorbt) , true );
   else
-    gtk_widget_set_sensitive( GTK_WIDGET(shadow_colorbt) , FALSE );
+    gtk_widget_set_sensitive( GTK_WIDGET(shadow_colorbt) , false );
 }
 
 
@@ -355,11 +355,11 @@ aosd_ui_configure_text ( aosd_cfg_t * cfg )
   GtkWidget *tex_font_shadow_colorbt[3];
   int i = 0;
 
-  tex_vbox = gtk_vbox_new( FALSE , 4 );
+  tex_vbox = gtk_vbox_new( false , 4 );
   gtk_container_set_border_width( GTK_CONTAINER(tex_vbox) , 6 );
 
   tex_font_frame = gtk_frame_new( _("Fonts") );
-  tex_font_grid = gtk_table_new (0, 0, FALSE);
+  tex_font_grid = gtk_table_new (0, 0, false);
   gtk_container_set_border_width( GTK_CONTAINER(tex_font_grid) , 6 );
   gtk_table_set_row_spacings( GTK_TABLE(tex_font_grid) , 4 );
   gtk_table_set_col_spacings( GTK_TABLE(tex_font_grid) , 4 );
@@ -369,10 +369,10 @@ aosd_ui_configure_text ( aosd_cfg_t * cfg )
     tex_font_label[i] = gtk_label_new( label_str );
     g_free( label_str );
     tex_font_fontbt[i] = gtk_font_button_new();
-    gtk_font_button_set_show_style( GTK_FONT_BUTTON(tex_font_fontbt[i]) , TRUE );
-    gtk_font_button_set_show_size( GTK_FONT_BUTTON(tex_font_fontbt[i]) , TRUE );
-    gtk_font_button_set_use_font( GTK_FONT_BUTTON(tex_font_fontbt[i]) , FALSE );
-    gtk_font_button_set_use_size( GTK_FONT_BUTTON(tex_font_fontbt[i]) , FALSE );
+    gtk_font_button_set_show_style( GTK_FONT_BUTTON(tex_font_fontbt[i]) , true );
+    gtk_font_button_set_show_size( GTK_FONT_BUTTON(tex_font_fontbt[i]) , true );
+    gtk_font_button_set_use_font( GTK_FONT_BUTTON(tex_font_fontbt[i]) , false );
+    gtk_font_button_set_use_size( GTK_FONT_BUTTON(tex_font_fontbt[i]) , false );
     gtk_font_button_set_font_name( GTK_FONT_BUTTON(tex_font_fontbt[i]) , cfg->text.fonts_name[i] );
 
     tex_font_colorbt[i] = gtk_color_button_new ();
@@ -380,13 +380,13 @@ aosd_ui_configure_text ( aosd_cfg_t * cfg )
      & cfg->text.fonts_color[i]);
 
     tex_font_shadow_togglebt[i] = gtk_toggle_button_new_with_label( _("Shadow") );
-    gtk_toggle_button_set_mode( GTK_TOGGLE_BUTTON(tex_font_shadow_togglebt[i]) , FALSE );
+    gtk_toggle_button_set_mode( GTK_TOGGLE_BUTTON(tex_font_shadow_togglebt[i]) , false );
 
     tex_font_shadow_colorbt[i] = gtk_color_button_new ();
     chooser_set_aosd_color ((GtkColorButton *) tex_font_shadow_colorbt[i],
      & cfg->text.fonts_shadow_color[i]);
 
-    gtk_widget_set_sensitive( tex_font_shadow_colorbt[i] , FALSE );
+    gtk_widget_set_sensitive( tex_font_shadow_colorbt[i] , false );
     g_signal_connect( G_OBJECT(tex_font_shadow_togglebt[i]) , "toggled" ,
                       G_CALLBACK(aosd_cb_configure_text_font_shadow_toggle) ,
                       tex_font_shadow_colorbt[i] );
@@ -404,7 +404,7 @@ aosd_ui_configure_text ( aosd_cfg_t * cfg )
     aosd_cb_list.append( tex_font_fontbt[i] , aosd_cb_configure_text_font_commit );
   }
   gtk_container_add( GTK_CONTAINER(tex_font_frame) , tex_font_grid );
-  gtk_box_pack_start( GTK_BOX(tex_vbox) , tex_font_frame , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(tex_vbox) , tex_font_frame , false , false , 0 );
 
   return tex_vbox;
 }
@@ -417,7 +417,7 @@ aosd_cb_configure_decoration_style_commit ( GtkWidget * lv , aosd_cfg_t * cfg )
   GtkTreeModel *model;
   GtkTreeIter iter;
 
-  if ( gtk_tree_selection_get_selected( sel , &model , &iter ) == TRUE )
+  if ( gtk_tree_selection_get_selected( sel , &model , &iter ) == true )
   {
     int deco_code = 0;
     gtk_tree_model_get( model , &iter , 1 , &deco_code , -1 );
@@ -451,7 +451,7 @@ aosd_ui_configure_decoration ( aosd_cfg_t * cfg )
   GtkWidget *dec_rstyleopts_frame, *dec_rstyleopts_grid;
   int colors_max_num = 0, i = 0;
 
-  dec_hbox = gtk_hbox_new( FALSE , 4 );
+  dec_hbox = gtk_hbox_new( false , 4 );
   gtk_container_set_border_width( GTK_CONTAINER(dec_hbox) , 6 );
 
   /* decoration style model
@@ -492,15 +492,15 @@ aosd_ui_configure_decoration ( aosd_cfg_t * cfg )
   gtk_container_add( GTK_CONTAINER(dec_rstyle_lv_frame) , dec_rstyle_lv_sw );
 
   gtk_tree_selection_select_iter( dec_rstyle_lv_sel , &iter_sel );
-  gtk_box_pack_start( GTK_BOX(dec_hbox) , dec_rstyle_lv_frame , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(dec_hbox) , dec_rstyle_lv_frame , false , false , 0 );
   aosd_cb_list.append( dec_rstyle_lv , aosd_cb_configure_decoration_style_commit );
 
-  dec_rstyle_hbox = gtk_vbox_new( FALSE , 4 );
-  gtk_box_pack_start( GTK_BOX(dec_hbox) , dec_rstyle_hbox , TRUE , TRUE , 0 );
+  dec_rstyle_hbox = gtk_vbox_new( false , 4 );
+  gtk_box_pack_start( GTK_BOX(dec_hbox) , dec_rstyle_hbox , true , true , 0 );
 
   /* in colors_max_num now there's the maximum number of colors used by decoration styles */
   dec_rstyleopts_frame = gtk_frame_new( _("Colors") );
-  dec_rstyleopts_grid = gtk_table_new (0, 0, FALSE);
+  dec_rstyleopts_grid = gtk_table_new (0, 0, false);
   gtk_container_set_border_width( GTK_CONTAINER(dec_rstyleopts_grid) , 6 );
   gtk_table_set_row_spacings( GTK_TABLE(dec_rstyleopts_grid) , 4 );
   gtk_table_set_col_spacings( GTK_TABLE(dec_rstyleopts_grid) , 8 );
@@ -509,7 +509,7 @@ aosd_ui_configure_decoration ( aosd_cfg_t * cfg )
   {
     GtkWidget *hbox, *label;
     char *label_str = nullptr;
-    hbox = gtk_hbox_new( FALSE , 4 );
+    hbox = gtk_hbox_new( false , 4 );
     label_str = g_strdup_printf( _("Color %i:") , i+1 );
     label = gtk_label_new( label_str );
     g_free( label_str );
@@ -517,13 +517,13 @@ aosd_ui_configure_decoration ( aosd_cfg_t * cfg )
     GtkWidget * colorbt = gtk_color_button_new ();
     chooser_set_aosd_color ((GtkColorButton *) colorbt, & cfg->decoration.colors[i]);
 
-    gtk_box_pack_start( GTK_BOX(hbox) , label , FALSE , FALSE , 0 );
-    gtk_box_pack_start( GTK_BOX(hbox) , colorbt , FALSE , FALSE , 0 );
+    gtk_box_pack_start( GTK_BOX(hbox) , label , false , false , 0 );
+    gtk_box_pack_start( GTK_BOX(hbox) , colorbt , false , false , 0 );
     gtk_table_attach_defaults( GTK_TABLE(dec_rstyleopts_grid) , hbox , (i % 3) , (i % 3) + 1, (i / 3) , (i / 3) + 1);
     g_object_set_data( G_OBJECT(colorbt) , "colnum" , GINT_TO_POINTER(i) );
     aosd_cb_list.append( colorbt , aosd_cb_configure_decoration_color_commit );
   }
-  gtk_box_pack_start( GTK_BOX(dec_rstyle_hbox) , dec_rstyleopts_frame , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(dec_rstyle_hbox) , dec_rstyleopts_frame , false , false , 0 );
 
   return dec_hbox;
 }
@@ -535,7 +535,7 @@ aosd_cb_configure_trigger_lvchanged ( GtkTreeSelection *sel , void * nb )
   GtkTreeModel *model;
   GtkTreeIter iter;
 
-  if ( gtk_tree_selection_get_selected( sel , &model , &iter ) == TRUE )
+  if ( gtk_tree_selection_get_selected( sel , &model , &iter ) == true )
   {
     int page_num = 0;
     gtk_tree_model_get( model , &iter , 2 , &page_num , -1 );
@@ -547,7 +547,7 @@ aosd_cb_configure_trigger_lvchanged ( GtkTreeSelection *sel , void * nb )
 static void
 aosd_cb_configure_trigger_commit ( GtkWidget * cbt , aosd_cfg_t * cfg )
 {
-  if ( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(cbt) ) == TRUE )
+  if ( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(cbt) ) == true )
   {
     int value = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(cbt),"code"));
     cfg->trigger.enabled[value] = true;
@@ -570,10 +570,10 @@ aosd_ui_configure_trigger ( aosd_cfg_t * cfg )
 
   tri_event_nb = gtk_notebook_new();
   gtk_notebook_set_tab_pos( GTK_NOTEBOOK(tri_event_nb) , GTK_POS_LEFT );
-  gtk_notebook_set_show_tabs( GTK_NOTEBOOK(tri_event_nb) , FALSE );
-  gtk_notebook_set_show_border( GTK_NOTEBOOK(tri_event_nb) , FALSE );
+  gtk_notebook_set_show_tabs( GTK_NOTEBOOK(tri_event_nb) , false );
+  gtk_notebook_set_show_border( GTK_NOTEBOOK(tri_event_nb) , false );
 
-  tri_hbox = gtk_hbox_new( FALSE , 4 );
+  tri_hbox = gtk_hbox_new( false , 4 );
   gtk_container_set_border_width( GTK_CONTAINER(tri_hbox) , 6 );
 
   /* trigger model
@@ -591,20 +591,20 @@ aosd_ui_configure_trigger ( aosd_cfg_t * cfg )
     gtk_list_store_set( tri_event_store , &iter ,
       0 , _(aosd_trigger_get_name( i )) ,
       1 , i , 2 , i , -1 );
-    vbox = gtk_vbox_new( FALSE , 0 );
+    vbox = gtk_vbox_new( false , 0 );
     gtk_container_set_border_width( GTK_CONTAINER(vbox) , 6 );
     label = gtk_label_new( _(aosd_trigger_get_desc( i )) );
-    gtk_label_set_line_wrap( GTK_LABEL(label) , TRUE );
+    gtk_label_set_line_wrap( GTK_LABEL(label) , true );
     gtk_label_set_max_width_chars( GTK_LABEL(label), 40 );
     gtk_misc_set_alignment( GTK_MISC(label) , 0.0 , 0.0 );
     checkbt = gtk_check_button_new_with_label( _("Enable trigger") );
     if ( cfg->trigger.enabled[i] )
-      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(checkbt) , TRUE );
+      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(checkbt) , true );
     else
-      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(checkbt) , FALSE );
-    gtk_box_pack_start( GTK_BOX(vbox) , checkbt , FALSE , FALSE , 0 );
-    gtk_box_pack_start( GTK_BOX(vbox) , gtk_hseparator_new() , FALSE , FALSE , 4 );
-    gtk_box_pack_start( GTK_BOX(vbox) , label , FALSE , FALSE , 0 );
+      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(checkbt) , false );
+    gtk_box_pack_start( GTK_BOX(vbox) , checkbt , false , false , 0 );
+    gtk_box_pack_start( GTK_BOX(vbox) , gtk_hseparator_new() , false , false , 4 );
+    gtk_box_pack_start( GTK_BOX(vbox) , label , false , false , 0 );
     frame = gtk_frame_new( nullptr );
     gtk_container_add( GTK_CONTAINER(frame) , vbox );
     gtk_notebook_append_page( GTK_NOTEBOOK(tri_event_nb) , frame , nullptr );
@@ -619,7 +619,7 @@ aosd_ui_configure_trigger ( aosd_cfg_t * cfg )
   gtk_tree_selection_set_mode( tri_event_lv_sel , GTK_SELECTION_BROWSE );
   g_signal_connect( G_OBJECT(tri_event_lv_sel) , "changed" ,
                     G_CALLBACK(aosd_cb_configure_trigger_lvchanged) , tri_event_nb );
-  if ( gtk_tree_model_get_iter_first( GTK_TREE_MODEL(tri_event_store) , &iter ) == TRUE )
+  if ( gtk_tree_model_get_iter_first( GTK_TREE_MODEL(tri_event_store) , &iter ) == true )
     gtk_tree_selection_select_iter( tri_event_lv_sel , &iter );
 
   tri_event_lv_rndr_text = gtk_cell_renderer_text_new();
@@ -633,9 +633,9 @@ aosd_ui_configure_trigger ( aosd_cfg_t * cfg )
   gtk_container_add( GTK_CONTAINER(tri_event_lv_frame) , tri_event_lv_sw );
   gtk_tree_selection_select_iter( tri_event_lv_sel , &iter );
 
-  gtk_box_pack_start( GTK_BOX(tri_hbox) , tri_event_lv_frame , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(tri_hbox) , tri_event_lv_frame , false , false , 0 );
 
-  gtk_box_pack_start( GTK_BOX(tri_hbox) , tri_event_nb , TRUE , TRUE , 0 );
+  gtk_box_pack_start( GTK_BOX(tri_hbox) , tri_event_nb , true , true , 0 );
 
   return tri_hbox;
 }
@@ -653,7 +653,7 @@ aosd_cb_configure_misc_transp_real_clicked ( GtkToggleButton * real_rbt , void *
     {
       gtk_image_set_from_icon_name( GTK_IMAGE(img) , "face-smile" , GTK_ICON_SIZE_MENU );
       gtk_label_set_text( GTK_LABEL(label) , _("Composite manager detected") );
-      gtk_widget_set_sensitive( GTK_WIDGET(status_hbox) , TRUE );
+      gtk_widget_set_sensitive( GTK_WIDGET(status_hbox) , true );
     }
     else
     {
@@ -661,14 +661,14 @@ aosd_cb_configure_misc_transp_real_clicked ( GtkToggleButton * real_rbt , void *
       gtk_label_set_text( GTK_LABEL(label) ,
         _("Composite manager not detected;\nunless you know that you have one running, "
           "please activate a composite manager otherwise the OSD won't work properly") );
-      gtk_widget_set_sensitive( GTK_WIDGET(status_hbox) , TRUE );
+      gtk_widget_set_sensitive( GTK_WIDGET(status_hbox) , true );
     }
   }
   else
   {
     gtk_image_set_from_icon_name( GTK_IMAGE(img) , "dialog-information" , GTK_ICON_SIZE_MENU );
     gtk_label_set_text( GTK_LABEL(label) , _("Composite manager not required for fake transparency") );
-    gtk_widget_set_sensitive( GTK_WIDGET(status_hbox) , FALSE );
+    gtk_widget_set_sensitive( GTK_WIDGET(status_hbox) , false );
   }
 }
 #endif
@@ -699,14 +699,14 @@ aosd_ui_configure_misc ( aosd_cfg_t * cfg )
   GtkWidget *mis_transp_status_frame, *mis_transp_status_hbox;
   GtkWidget *mis_transp_status_img, *mis_transp_status_label;
 
-  mis_vbox = gtk_vbox_new( FALSE , 0 );
+  mis_vbox = gtk_vbox_new( false , 0 );
   gtk_container_set_border_width( GTK_CONTAINER(mis_vbox) , 6 );
 
-  mis_transp_vbox = gtk_vbox_new( FALSE , 0 );
+  mis_transp_vbox = gtk_vbox_new( false , 0 );
   mis_transp_frame = gtk_frame_new( _("Transparency") );
   gtk_container_set_border_width( GTK_CONTAINER(mis_transp_vbox) , 6 );
   gtk_container_add( GTK_CONTAINER(mis_transp_frame) , mis_transp_vbox );
-  gtk_box_pack_start( GTK_BOX(mis_vbox) , mis_transp_frame , FALSE , FALSE , 0 );
+  gtk_box_pack_start( GTK_BOX(mis_vbox) , mis_transp_frame , false , false , 0 );
 
   mis_transp_fake_rbt = gtk_radio_button_new_with_label( nullptr ,
                           _("Fake transparency") );
@@ -716,22 +716,22 @@ aosd_ui_configure_misc ( aosd_cfg_t * cfg )
                      GINT_TO_POINTER(AOSD_MISC_TRANSPARENCY_FAKE) );
   g_object_set_data( G_OBJECT(mis_transp_real_rbt) , "val" ,
                      GINT_TO_POINTER(AOSD_MISC_TRANSPARENCY_REAL) );
-  gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_fake_rbt , TRUE , TRUE , 0 );
-  gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_real_rbt , TRUE , TRUE , 0 );
+  gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_fake_rbt , true , true , 0 );
+  gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_real_rbt , true , true , 0 );
 
-  mis_transp_status_hbox = gtk_hbox_new( FALSE , 4 );
+  mis_transp_status_hbox = gtk_hbox_new( false , 4 );
   mis_transp_status_frame = gtk_frame_new( nullptr );
   gtk_container_set_border_width( GTK_CONTAINER(mis_transp_status_hbox) , 3 );
   gtk_container_add( GTK_CONTAINER(mis_transp_status_frame) , mis_transp_status_hbox );
-  gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_status_frame , TRUE , TRUE , 0 );
+  gtk_box_pack_start( GTK_BOX(mis_transp_vbox) , mis_transp_status_frame , true , true , 0 );
 
   mis_transp_status_img = gtk_image_new();
   gtk_misc_set_alignment( GTK_MISC(mis_transp_status_img) , 0.5 , 0 );
   mis_transp_status_label = gtk_label_new( "" );
   gtk_misc_set_alignment( GTK_MISC(mis_transp_status_label) , 0 , 0.5 );
-  gtk_label_set_line_wrap( GTK_LABEL(mis_transp_status_label) , TRUE );
-  gtk_box_pack_start( GTK_BOX(mis_transp_status_hbox) , mis_transp_status_img , FALSE , FALSE , 0 );
-  gtk_box_pack_start( GTK_BOX(mis_transp_status_hbox) , mis_transp_status_label , TRUE , TRUE , 0 );
+  gtk_label_set_line_wrap( GTK_LABEL(mis_transp_status_label) , true );
+  gtk_box_pack_start( GTK_BOX(mis_transp_status_hbox) , mis_transp_status_img , false , false , 0 );
+  gtk_box_pack_start( GTK_BOX(mis_transp_status_hbox) , mis_transp_status_label , true , true , 0 );
   g_object_set_data( G_OBJECT(mis_transp_status_hbox) , "img" , mis_transp_status_img );
   g_object_set_data( G_OBJECT(mis_transp_status_hbox) , "label" , mis_transp_status_label );
 
@@ -743,26 +743,26 @@ aosd_ui_configure_misc ( aosd_cfg_t * cfg )
   if ( aosd_osd_check_composite_ext() )
   {
     if ( cfg->misc.transparency_mode == AOSD_MISC_TRANSPARENCY_FAKE )
-      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(mis_transp_fake_rbt) , TRUE );
+      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(mis_transp_fake_rbt) , true );
     else
-      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(mis_transp_real_rbt) , TRUE );
+      gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(mis_transp_real_rbt) , true );
   }
   else
   {
-    gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(mis_transp_fake_rbt) , TRUE );
-    gtk_widget_set_sensitive( GTK_WIDGET(mis_transp_real_rbt) , FALSE );
+    gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(mis_transp_fake_rbt) , true );
+    gtk_widget_set_sensitive( GTK_WIDGET(mis_transp_real_rbt) , false );
     gtk_image_set_from_icon_name( GTK_IMAGE(mis_transp_status_img) ,
       "dialog-error" , GTK_ICON_SIZE_MENU );
     gtk_label_set_text( GTK_LABEL(mis_transp_status_label) , _("Composite extension not loaded") );
-    gtk_widget_set_sensitive( GTK_WIDGET(mis_transp_status_hbox) , FALSE );
+    gtk_widget_set_sensitive( GTK_WIDGET(mis_transp_status_hbox) , false );
   }
 #else
-  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(mis_transp_fake_rbt) , TRUE );
-  gtk_widget_set_sensitive( GTK_WIDGET(mis_transp_real_rbt) , FALSE );
+  gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(mis_transp_fake_rbt) , true );
+  gtk_widget_set_sensitive( GTK_WIDGET(mis_transp_real_rbt) , false );
   gtk_image_set_from_icon_name( GTK_IMAGE(mis_transp_status_img) ,
     "dialog-error" , GTK_ICON_SIZE_MENU );
   gtk_label_set_text( GTK_LABEL(mis_transp_status_label) , _("Composite extension not available") );
-  gtk_widget_set_sensitive( GTK_WIDGET(mis_transp_status_hbox) , FALSE );
+  gtk_widget_set_sensitive( GTK_WIDGET(mis_transp_status_hbox) , false );
 #endif
 
   aosd_cb_list.append( mis_transp_vbox , aosd_cb_configure_misc_transp_commit );
