@@ -374,7 +374,7 @@ Tuple FFaudio::read_tuple (const char * filename, VFSFile & file)
     }
 
     if (tuple && ! file.fseek (0, VFS_SEEK_SET))
-        audtag::tuple_read (tuple, file);
+        audtag::read_tag (file, & tuple, nullptr);
 
     return tuple;
 }
