@@ -21,6 +21,7 @@
 #include <gtk/gtk.h>
 
 #include <libaudcore/drct.h>
+#include <libaudcore/hook.h>
 #include <libaudcore/i18n.h>
 #include <libaudcore/interface.h>
 #include <libaudcore/playlist.h>
@@ -50,6 +51,7 @@ static void add_files () { audgui_run_filebrowser (false); }
 static void add_url () { audgui_show_add_url_window (false); }
 
 static void configure_effects () { audgui_show_prefs_for_plugin_type (PluginType::Effect); }
+static void configure_output () { audgui_show_prefs_for_plugin_type (PluginType::Output); }
 static void configure_visualizations () { audgui_show_prefs_for_plugin_type (PluginType::Vis); }
 
 static void pl_sort_track () { aud_playlist_sort_by_scheme (aud_playlist_get_active (), Playlist::Track); }
@@ -78,12 +80,6 @@ static void pl_sort_selected_custom () { aud_playlist_sort_selected_by_scheme (a
 static void pl_reverse_selected () { aud_playlist_reverse_selected (aud_playlist_get_active ()); }
 static void pl_random_selected () { aud_playlist_randomize_selected (aud_playlist_get_active ()); }
 
-static void pl_new ()
-{
-    aud_playlist_insert (-1);
-    aud_playlist_set_active (aud_playlist_count () - 1);
-}
-
 static void pl_play () { aud_playlist_play (aud_playlist_get_active ()); }
 static void pl_refresh () { aud_playlist_rescan (aud_playlist_get_active ()); }
 static void pl_remove_failed () { aud_playlist_remove_failed (aud_playlist_get_active ()); }
@@ -122,6 +118,15 @@ static GtkWidget * get_services_pl () { return audgui_get_plugin_menu (AudMenuID
 static void volume_up () { aud_drct_set_volume_main (aud_drct_get_volume_main () + 5); }
 static void volume_down () { aud_drct_set_volume_main (aud_drct_get_volume_main () - 5); }
 
+static void toggle_record ()
+{
+    if (! aud_drct_enable_record (aud_get_bool ("gtkui", "record")))
+    {
+        aud_set_bool ("gtkui", "record", aud_drct_get_record_enabled ());
+        hook_call ("gtkui set record", nullptr);
+    }
+}
+
 static const AudguiMenuItem file_items[] = {
     MenuCommand (N_("_Open Files ..."), "document-open", 'o', CTRL, open_files),
     MenuCommand (N_("Open _URL ..."), "folder-remote", 'l', CTRL, open_url),
@@ -144,6 +149,7 @@ static const AudguiMenuItem playback_items[] = {
     MenuSep (),
     MenuToggle (N_("_Repeat"), nullptr, 'r', CTRL, nullptr, "repeat", nullptr, "set repeat"),
     MenuToggle (N_("S_huffle"), nullptr, 's', CTRL, nullptr, "shuffle", nullptr, "set shuffle"),
+    MenuToggle (N_("Shuffle by Albu_m"), nullptr, NONE, nullptr, "album_shuffle", nullptr, "set album_shuffle"),
     MenuToggle (N_("N_o Playlist Advance"), nullptr, 'n', CTRL, nullptr, "no_playlist_advance", nullptr, "set no_playlist_advance"),
     MenuToggle (N_("Stop A_fter This Song"), nullptr, 'm', CTRL, nullptr, "stop_after_current_song", nullptr, "set stop_after_current_song"),
     MenuSep (),
@@ -203,7 +209,7 @@ static const AudguiMenuItem playlist_items[] = {
     MenuSub (N_("Remove _Duplicates"), "edit-copy", {dupe_items}),
     MenuCommand (N_("Remove _Unavailable Files"), "dialog-warning", NONE, pl_remove_failed),
     MenuSep (),
-    MenuCommand (N_("_New"), "document-new", 't', CTRL, pl_new),
+    MenuCommand (N_("_New"), "document-new", 't', CTRL, (GCallback) aud_playlist_new),
     MenuCommand (N_("Ren_ame ..."), "insert-text", GDK_KEY_F2, (GdkModifierType) 0, pl_rename),
     MenuCommand (N_("Remo_ve"), "edit-delete", 'w', CTRL, pl_close),
     MenuSep (),
@@ -218,9 +224,11 @@ static const AudguiMenuItem output_items[] = {
     MenuCommand (N_("Volume _Up"), "audio-volume-high", '+', CTRL, volume_up),
     MenuCommand (N_("Volume _Down"), "audio-volume-low", '-', CTRL, volume_down),
     MenuSep (),
-    MenuCommand (N_("_Equalizer"), "multimedia-volume-control", 'e', CTRL, audgui_show_equalizer_window),
+    MenuCommand (N_("_Equalizer ..."), "multimedia-volume-control", 'e', CTRL, audgui_show_equalizer_window),
+    MenuCommand (N_("E_ffects ..."), nullptr, NONE, configure_effects),
     MenuSep (),
-    MenuCommand (N_("E_ffects ..."), nullptr, NONE, configure_effects)
+    MenuToggle (N_("_Record Stream"), nullptr, 'd', CTRL, "gtkui", "record", toggle_record, "gtkui set record"),
+    MenuCommand (N_("Audio _Settings ..."), "audio-card", NONE, configure_output)
 };
 
 static const AudguiMenuItem view_items[] = {
