@@ -22,16 +22,18 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-#include <libaudcore/runtime.h>
+#define AUD_PLUGIN_GLIB_ONLY
+#include <libaudcore/audstrings.h>
 #include <libaudcore/drct.h>
+#include <libaudcore/hook.h>
 #include <libaudcore/i18n.h>
+#include <libaudcore/mainloop.h>
 #include <libaudcore/playlist.h>
 #include <libaudcore/plugin.h>
 #include <libaudcore/plugins.h>
 #include <libaudcore/runtime.h>
-#include <libaudcore/audstrings.h>
-#include <libaudcore/hook.h>
 #include <libaudgui/libaudgui.h>
+#include <libaudgui/libaudgui-gtk.h>
 
 #include "gtkui.h"
 #include "layout.h"
@@ -53,13 +55,12 @@ static const char * const gtkui_defaults[] = {
     "autoscroll", "TRUE",
     "playlist_columns", "title artist album queued length",
     "playlist_headers", "TRUE",
+    "record", "FALSE",
     "show_remaining_time", "FALSE",
     "step_size", "5",
 
     "player_x", "-1000",
     "player_y", "-1000",
-    "player_width", "760",
-    "player_height", "460",
 
     nullptr
 };
@@ -113,7 +114,6 @@ static PluginHandle * search_tool;
 
 static GtkWidget * volume;
 static bool volume_slider_is_moving = false;
-static unsigned update_volume_timeout_source = 0;
 static unsigned long volume_change_handler_id;
 
 static GtkAccelGroup * accel;
@@ -121,14 +121,13 @@ static GtkAccelGroup * accel;
 static GtkWidget * window, * vbox_outer, * menu_box, * menu, * toolbar, * vbox,
  * infoarea, * statusbar;
 static GtkToolItem * menu_button, * search_button, * button_play, * button_stop,
- * button_shuffle, * button_repeat;
+ * button_record, * button_shuffle, * button_repeat;
 static GtkWidget * slider, * label_time;
 static GtkWidget * menu_main, * menu_rclick, * menu_tab;
 
-static gboolean slider_is_moving = false;
+static bool slider_is_moving = false;
 static int slider_seek_time = -1;
-static unsigned delayed_title_change_source = 0;
-static unsigned update_song_timeout_source = 0;
+static QueuedFunc delayed_title_change;
 
 static void save_window_size ()
 {
@@ -144,11 +143,17 @@ static void save_window_size ()
 
 static void restore_window_size ()
 {
+    int dpi = audgui_get_dpi ();
     int x = aud_get_int ("gtkui", "player_x");
     int y = aud_get_int ("gtkui", "player_y");
     int w = aud_get_int ("gtkui", "player_width");
     int h = aud_get_int ("gtkui", "player_height");
 
+    if (w < 1)
+        w = 8 * dpi;
+    if (h < 1)
+        h = 5 * dpi;
+
     gtk_window_set_default_size ((GtkWindow *) window, w, h);
 
     if (x > -1000 && y > -1000)
@@ -205,13 +210,9 @@ void clear_ab_repeat ()
     aud_drct_set_ab_repeat (-1, -1);
 }
 
-static gboolean title_change_cb ()
+static void title_change (void * = nullptr)
 {
-    if (delayed_title_change_source)
-    {
-        g_source_remove (delayed_title_change_source);
-        delayed_title_change_source = 0;
-    }
+    delayed_title_change.stop ();
 
     if (aud_drct_get_playing ())
     {
@@ -226,8 +227,6 @@ static gboolean title_change_cb ()
     }
     else
         gtk_window_set_title ((GtkWindow *) window, _("Audacious"));
-
-    return false;
 }
 
 void GtkUI::show (bool show)
@@ -259,12 +258,12 @@ static void set_time_label (int time, int len)
 {
     char s[128] = "<b>";
 
-    if (len && aud_get_bool ("gtkui", "show_remaining_time"))
+    if (len > 0 && aud_get_bool ("gtkui", "show_remaining_time"))
         append_str (s, sizeof s, str_format_time (len - time));
     else
         append_str (s, sizeof s, str_format_time (time));
 
-    if (len)
+    if (len > 0)
     {
         append_str (s, sizeof s, " / ");
         append_str (s, sizeof s, str_format_time (len));
@@ -297,10 +296,10 @@ static void set_slider (int time)
     gtk_range_set_value ((GtkRange *) slider, time);
 }
 
-static gboolean time_counter_cb ()
+static void time_counter_cb (void * = nullptr)
 {
     if (slider_is_moving)
-        return true;
+        return;
 
     slider_seek_time = -1;  // delayed reset to avoid seeking twice
 
@@ -311,39 +310,24 @@ static gboolean time_counter_cb ()
         set_slider (time);
 
     set_time_label (time, length);
-
-    return true;
 }
 
 static void do_seek (int time)
 {
-    int length = aud_drct_get_length ();
-    time = aud::clamp (time, 0, length);
-
-    set_slider (time);
-    set_time_label (time, length);
     aud_drct_seek (time);
-
-    // Trick: Unschedule and then schedule the update function.  This gives the
-    // player 1/4 second to perform the seek before we update the display again,
-    // in an attempt to reduce flickering.
-    if (update_song_timeout_source)
-    {
-        g_source_remove (update_song_timeout_source);
-        update_song_timeout_source = g_timeout_add (250, (GSourceFunc) time_counter_cb, nullptr);
-    }
+    time_counter_cb ();
 }
 
 static gboolean ui_slider_change_value_cb (GtkRange * range,
  GtkScrollType scroll, double value)
 {
-    int length = aud_drct_get_length ();
-    int time = aud::clamp ((int) value, 0, length);
-
-    set_time_label (time, length);
+    int time = value;
 
     if (slider_is_moving)
+    {
         slider_seek_time = time;
+        set_time_label (time, aud_drct_get_length ());
+    }
     else if (time != slider_seek_time)  // avoid seeking twice
         do_seek (time);
 
@@ -395,21 +379,19 @@ static void ui_volume_released_cb (GtkButton * button)
     volume_slider_is_moving = false;
 }
 
-static gboolean ui_volume_slider_update (void * button)
+static void ui_volume_slider_update (void * button)
 {
-    if (volume_slider_is_moving || ! button)
-        return true;
+    if (volume_slider_is_moving)
+        return;
 
     int volume = aud_drct_get_volume_main ();
 
     if (volume == (int) gtk_scale_button_get_value ((GtkScaleButton *) button))
-        return true;
+        return;
 
     g_signal_handler_block (button, volume_change_handler_id);
     gtk_scale_button_set_value ((GtkScaleButton *) button, volume);
     g_signal_handler_unblock (button, volume_change_handler_id);
-
-    return true;
 }
 
 static void set_slider_length (int length)
@@ -440,44 +422,28 @@ static void ui_playback_begin ()
     pause_cb ();
     gtk_widget_set_sensitive ((GtkWidget *) button_stop, true);
 
-    if (delayed_title_change_source)
-        g_source_remove (delayed_title_change_source);
-
     /* If "title change" is not called by 1/4 second after starting playback,
      * show "Buffering ..." as the window title. */
-    delayed_title_change_source = g_timeout_add (250, (GSourceFunc)
-     title_change_cb, nullptr);
+    delayed_title_change.queue (250, title_change, nullptr);
 }
 
 static void ui_playback_ready ()
 {
-    title_change_cb ();
+    title_change ();
     set_slider_length (aud_drct_get_length ());
     time_counter_cb ();
 
     /* update time counter 4 times a second */
-    if (! update_song_timeout_source)
-        update_song_timeout_source = g_timeout_add (250, (GSourceFunc)
-         time_counter_cb, nullptr);
+    timer_add (TimerRate::Hz4, time_counter_cb);
 
     gtk_widget_show (label_time);
 }
 
 static void ui_playback_stop ()
 {
-    if (update_song_timeout_source)
-    {
-        g_source_remove (update_song_timeout_source);
-        update_song_timeout_source = 0;
-    }
-
-    if (delayed_title_change_source)
-        g_source_remove (delayed_title_change_source);
-
-    /* Don't update the window title immediately; we may be about to start
-     * another song. */
-    delayed_title_change_source = g_idle_add ((GSourceFunc) title_change_cb, nullptr);
+    timer_remove (TimerRate::Hz4, time_counter_cb);
 
+    title_change ();
     gtk_tool_button_set_icon_name ((GtkToolButton *) button_play, "media-playback-start");
     gtk_widget_set_sensitive ((GtkWidget *) button_stop, false);
     gtk_widget_hide (slider);
@@ -655,7 +621,7 @@ static gboolean playlist_keypress_cb (GtkWidget * widget, GdkEventKey * event)
     return false;
 }
 
-static void update_toggles (void * data, void * user)
+static void update_toggles (void * = nullptr, void * = nullptr)
 {
     gtk_toggle_tool_button_set_active ((GtkToggleToolButton *) button_repeat,
      aud_get_bool (nullptr, "repeat"));
@@ -673,6 +639,28 @@ static void toggle_shuffle (GtkToggleToolButton * button)
     aud_set_bool (nullptr, "shuffle", gtk_toggle_tool_button_get_active (button));
 }
 
+static void toggle_record (GtkToggleToolButton * button)
+{
+    if (! aud_drct_enable_record (gtk_toggle_tool_button_get_active (button)))
+        gtk_toggle_tool_button_set_active (button, aud_drct_get_record_enabled ());
+}
+
+static void record_toggled (void * = nullptr, void * = nullptr)
+{
+    bool supported = (bool) aud_drct_get_record_plugin ();
+    bool enabled = aud_drct_get_record_enabled ();
+
+    gtk_widget_set_sensitive ((GtkWidget *) button_record, supported);
+    gtk_toggle_tool_button_set_active ((GtkToggleToolButton *) button_record, enabled);
+
+    /* update menu item */
+    if (enabled != aud_get_bool ("gtkui", "record"))
+    {
+        aud_set_bool ("gtkui", "record", enabled);
+        hook_call ("gtkui set record", nullptr);
+    }
+}
+
 static void toggle_search_tool (GtkToggleToolButton * button)
 {
     aud_plugin_enable (search_tool, gtk_toggle_tool_button_get_active (button));
@@ -696,7 +684,7 @@ static void config_save ()
 
 static void ui_hooks_associate ()
 {
-    hook_associate ("title change", (HookFunction) title_change_cb, nullptr);
+    hook_associate ("title change", (HookFunction) title_change, nullptr);
     hook_associate ("playback begin", (HookFunction) ui_playback_begin, nullptr);
     hook_associate ("playback ready", (HookFunction) ui_playback_ready, nullptr);
     hook_associate ("playback pause", (HookFunction) pause_cb, nullptr);
@@ -708,12 +696,13 @@ static void ui_hooks_associate ()
     hook_associate ("playlist position", ui_playlist_notebook_position, nullptr);
     hook_associate ("set shuffle", update_toggles, nullptr);
     hook_associate ("set repeat", update_toggles, nullptr);
+    hook_associate ("enable record", record_toggled, nullptr);
     hook_associate ("config save", (HookFunction) config_save, nullptr);
 }
 
 static void ui_hooks_disassociate ()
 {
-    hook_dissociate ("title change", (HookFunction) title_change_cb);
+    hook_dissociate ("title change", (HookFunction) title_change);
     hook_dissociate ("playback begin", (HookFunction) ui_playback_begin);
     hook_dissociate ("playback ready", (HookFunction) ui_playback_ready);
     hook_dissociate ("playback pause", (HookFunction) pause_cb);
@@ -725,6 +714,7 @@ static void ui_hooks_disassociate ()
     hook_dissociate ("playlist position", ui_playlist_notebook_position);
     hook_dissociate ("set shuffle", update_toggles);
     hook_dissociate ("set repeat", update_toggles);
+    hook_dissociate ("enable record", record_toggled);
     hook_dissociate ("config save", (HookFunction) config_save);
 }
 
@@ -778,9 +768,6 @@ static void remove_dock_plugins ()
 
 bool GtkUI::init ()
 {
-    if (aud_get_mainloop_type () != MainloopType::GLib)
-        return false;
-
     audgui_init ();
 
     search_tool = aud_plugin_lookup_basename ("search-tool");
@@ -802,6 +789,7 @@ bool GtkUI::init ()
 
     toolbar = gtk_toolbar_new ();
     gtk_toolbar_set_style ((GtkToolbar *) toolbar, GTK_TOOLBAR_ICONS);
+    gtk_toolbar_set_show_arrow ((GtkToolbar *) toolbar, false);
     gtk_box_pack_start ((GtkBox *) vbox_outer, toolbar, false, false, 0);
 
     /* search button */
@@ -817,10 +805,12 @@ bool GtkUI::init ()
     /* playback buttons */
     toolbar_button_add (toolbar, button_open_pressed, "document-open");
     toolbar_button_add (toolbar, button_add_pressed, "list-add");
-    button_play = toolbar_button_add (toolbar, aud_drct_play_pause, "media-playback-start");
-    button_stop = toolbar_button_add (toolbar, aud_drct_stop, "media-playback-stop");
     toolbar_button_add (toolbar, aud_drct_pl_prev, "media-skip-backward");
     toolbar_button_add (toolbar, aud_drct_pl_next, "media-skip-forward");
+    button_play = toolbar_button_add (toolbar, aud_drct_play_pause, "media-playback-start");
+    button_stop = toolbar_button_add (toolbar, aud_drct_stop, "media-playback-stop");
+    button_record = toggle_button_new ("media-record", toggle_record);
+    gtk_toolbar_insert ((GtkToolbar *) toolbar, button_record, -1);
 
     /* time slider and label */
     GtkToolItem * boxitem1 = gtk_tool_item_new ();
@@ -832,7 +822,7 @@ bool GtkUI::init ()
 
     slider = gtk_hscale_new (nullptr);
     gtk_scale_set_draw_value ((GtkScale *) slider, false);
-    gtk_widget_set_size_request (slider, 120, -1);
+    gtk_widget_set_size_request (slider, audgui_get_dpi () * 5 / 4, -1);
     gtk_widget_set_can_focus (slider, false);
     gtk_box_pack_start ((GtkBox *) box1, slider, true, true, 6);
 
@@ -898,7 +888,8 @@ bool GtkUI::init ()
     volume_change_handler_id = g_signal_connect (volume, "value-changed", (GCallback) ui_volume_value_changed_cb, nullptr);
     g_signal_connect (volume, "pressed", (GCallback) ui_volume_pressed_cb, nullptr);
     g_signal_connect (volume, "released", (GCallback) ui_volume_released_cb, nullptr);
-    update_volume_timeout_source = g_timeout_add (250, (GSourceFunc) ui_volume_slider_update, volume);
+
+    timer_add (TimerRate::Hz4, ui_volume_slider_update, volume);
 
     g_signal_connect (window, "map-event", (GCallback) window_mapped_cb, nullptr);
     g_signal_connect (window, "delete-event", (GCallback) window_delete, nullptr);
@@ -914,12 +905,13 @@ bool GtkUI::init ()
     else
         ui_playback_stop ();
 
-    title_change_cb ();
+    title_change ();
+
+    update_toggles ();
+    record_toggled ();
 
     gtk_widget_show_all (vbox_outer);
 
-    update_toggles (nullptr, nullptr);
-
     menu_rclick = make_menu_rclick (accel);
     menu_tab = make_menu_tab (accel);
 
@@ -938,23 +930,9 @@ void GtkUI::cleanup ()
     gtk_widget_destroy (menu_rclick);
     gtk_widget_destroy (menu_tab);
 
-    if (update_song_timeout_source)
-    {
-        g_source_remove (update_song_timeout_source);
-        update_song_timeout_source = 0;
-    }
-
-    if (update_volume_timeout_source)
-    {
-        g_source_remove (update_volume_timeout_source);
-        update_volume_timeout_source = 0;
-    }
-
-    if (delayed_title_change_source)
-    {
-        g_source_remove (delayed_title_change_source);
-        delayed_title_change_source = 0;
-    }
+    timer_remove (TimerRate::Hz4, time_counter_cb);
+    timer_remove (TimerRate::Hz4, ui_volume_slider_update);
+    delayed_title_change.stop ();
 
     ui_hooks_disassociate ();
 
