@@ -22,20 +22,19 @@
 
 #include <libaudcore/hook.h>
 #include <libaudcore/index.h>
+#include <libaudcore/mainloop.h>
 #include <libaudcore/objects.h>
 
 #include "dialog_windows.h"
 #include "info_bar.h"
 
 #include <QMainWindow>
-#include <QTimer>
 #include <QVBoxLayout>
 
 class FilterInput;
 class PlaylistTabs;
 class PluginHandle;
-
-struct DockWidget;
+class PluginWidget;
 
 class MainWindow : public QMainWindow
 {
@@ -55,7 +54,7 @@ private:
     QAction * toolButtonRepeat;
     QAction * toolButtonShuffle;
 
-    QTimer buffering_timer;
+    QueuedFunc buffering_timer;
 
     void closeEvent (QCloseEvent * e);
     void keyPressEvent (QKeyEvent * e);
@@ -64,12 +63,10 @@ private:
     void setupActions ();
     void readSettings ();
 
-    void update_play_pause ();
-    void show_buffering ();
-
     void add_dock_plugins ();
     void remove_dock_plugins ();
 
+    void update_play_pause ();
     void title_change_cb ();
     void playback_begin_cb ();
     void playback_ready_cb ();
@@ -77,13 +74,14 @@ private:
     void playback_stop_cb ();
     void update_toggles_cb ();
 
+    PluginWidget * find_dock_plugin (PluginHandle * plugin);
     void add_dock_plugin_cb (PluginHandle * plugin);
     void remove_dock_plugin_cb (PluginHandle * plugin);
 
     const HookReceiver<MainWindow>
      hook1 {"title change", this, & MainWindow::title_change_cb},
      hook2 {"playback begin", this, & MainWindow::playback_begin_cb},
-     hook3 {"playback ready", this, & MainWindow::playback_ready_cb},
+     hook3 {"playback ready", this, & MainWindow::title_change_cb},
      hook4 {"playback pause", this, & MainWindow::pause_cb},
      hook5 {"playback unpause", this, & MainWindow::pause_cb},
      hook6 {"playback stop", this, & MainWindow::playback_stop_cb},
@@ -96,7 +94,7 @@ private:
      plugin_hook1 {"dock plugin enabled", this, & MainWindow::add_dock_plugin_cb},
      plugin_hook2 {"dock plugin disabled", this, & MainWindow::remove_dock_plugin_cb};
 
-    Index<DockWidget> dock_widgets;
+    Index<PluginWidget *> dock_widgets;
     int playing_id = -1;
 };
 
